@@ -8,7 +8,7 @@ use Class::Utils qw(set_params split_params);
 use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Process 'Tags'.
 sub _process {
@@ -24,6 +24,9 @@ sub _process {
 
 	$self->{'tags'}->put(
 		['b', 'input'],
+		$input->autofocus ? (
+			['a', 'autofocus', 'autofocus'],
+		) : (),
 		defined $input->css_class ? (
 			['a', 'class', $input->css_class],
 		) : (),
@@ -284,6 +287,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
